# Facilyst

[![PyPI Latest Release](https://img.shields.io/pypi/v/facilyst.svg)](https://pypi.org/project/facilyst/)
[![Package Status](https://img.shields.io/pypi/status/facilyst.svg)](https://pypi.org/project/facilyst/)
[![Unit Tests - Linux](https://github.com/Parthiv-Naresh/facilyst/actions/workflows/linux_unit_tests.yml/badge.svg?branch=main&event=push)](https://github.com/Parthiv-Naresh/facilyst/actions/workflows/linux_unit_tests.yml)
[![Coverage](https://codecov.io/gh/ParthivNaresh/facilyst/branch/main/graphs/badge.svg?branch=main)](https://codecov.io/gh/ParthivNaresh/facilyst)
[![License](https://img.shields.io/pypi/l/facilyst.svg)](https://github.com/Parthiv-Naresh/facilyst/blob/main/LICENSE)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Imports: isort](https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336)](https://pycqa.github.io/isort/)


Facil • yst

Facilis - Latin for easy, ready, or quick.

Analyst - Leaving this blank because I don't think anyone knows.


As a software developer in machine learning, I often find myself in the awkward position of building features and expanding use cases without easy access to data to test them with.
Sometimes it could be as simple as a Pandas DataFrame with different data types just so I have something basic to throw at my code, and in other cases I might need a sinusoidal wave with varying frequency 
and amplitude consisting of an upwards trend projected over a staggered datetime horizon.

Instead of having to constantly look up the right functions in order to meet these data needs, and then search through StackOverflow or documentation to figure out
how to plot it in a visually appealing way, I wanted a library that could provide a simple interface that made it easy to facilitate the work of an analyst/developer.


## Installation
Install from [PyPI](https://pypi.org/project/facilyst/)

`pip install facilyst`
